**********************************
Built-in synapse types
**********************************

ANNarchy provides standard spiking synapse models, similar to the ones defined in PyNN (`http://neuralensemble.org/docs/PyNN/reference/plasticitymodels.html <http://neuralensemble.org/docs/PyNN/reference/plasticitymodels.html>`_).

.. contents::
   :local:

Rate-coded
======================

.. autodata:: ANNarchy.models.Hebb

.. autodata:: ANNarchy.models.Oja

.. autodata:: ANNarchy.models.IBCM

Short-term plasticity
======================

.. autodata:: ANNarchy.models.STP

Spike-timing dependent plasticity
===================================

.. autodata:: ANNarchy.models.STDP
